#[non_exhaustive]pub enum HostCommand {
Init {
step_budget: u64,
allowed_hosts: Vec<String>,
},
Run {
input: String,
},
Cancel,
Mount {
path: String,
},
ReadFile {
path: String,
},
WriteFile {
path: String,
data: Vec<u8>,
},
ListDir {
path: String,
},
}Expand description
A command sent from the host to the worker.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Init
Initialize the shell runtime with optional configuration.
Fields
Run
Execute a shell command string.
Cancel
Cancel the currently running execution.
Mount
Mount a virtual filesystem at the given path.
ReadFile
Read a file from the virtual filesystem.
WriteFile
Write data to a file in the virtual filesystem.
Fields
ListDir
List directory contents.