Message protocol for the wasmsh browser worker bridge.
Defines versioned, serializable messages exchanged between the host page and the wasmsh Web Worker.
Protocol version
Current version: 0.1.0
Enums
- Diagnostic
Level - Diagnostic severity level.
- Host
Command - A command sent from the host to the worker.
- Worker
Event - An event sent from the worker to the host.
Constants
- PROTOCOL_
VERSION - Protocol version string.